/*
 * Copyright (c) 2017, 2025, Oracle and/or its affiliates.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is designed to work with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms,
 * as designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have either included with
 * the program or referenced in the documentation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 */

#ifndef UNITTEST_GUNIT_XPLUGIN_XCL_MOCK_QUERY_INSTANCE_H_
#define UNITTEST_GUNIT_XPLUGIN_XCL_MOCK_QUERY_INSTANCE_H_

#include <gmock/gmock.h>

#include "plugin/x/client/xquery_instances.h"

namespace xcl {
namespace test {
namespace mock {

class Query_instances : public xcl::Query_instances {
 public:
  Query_instances();
  virtual ~Query_instances() override;

  MOCK_METHOD(Instance_id, instances_fetch_begin, (), (override));
  MOCK_METHOD(void, instances_fetch_end, (), (override));
  MOCK_METHOD(bool, is_instance_active, (const Instance_id id), (override));
};

}  // namespace mock
}  // namespace test
}  // namespace xcl

#endif  // UNITTEST_GUNIT_XPLUGIN_XCL_MOCK_QUERY_INSTANCE_H_
